@@ -67,7 +67,6 @@ extensions = [
     "sphinx.ext.autodoc",
     "sphinx.ext.autosectionlabel",
     "sphinx.ext.doctest",
-    "sphinx.ext.graphviz",
     "sphinx.ext.intersphinx",
     "sphinx.ext.mathjax",
     "sphinx.ext.napoleon",
@@ -141,6 +140,7 @@ html_title = "AmpForm"
 pygments_style = "sphinx"
 todo_include_todos = False
 viewcode_follow_imported_members = True
+panels_add_bootstrap_css = False  # remove panels css to get wider main content
 
 # Cross-referencing configuration
 default_role = "py:obj"
@@ -174,7 +174,7 @@ intersphinx_mapping = {
     "ipywidgets": ("https://ipywidgets.readthedocs.io/en/stable", None),
     "matplotlib": ("https://matplotlib.org/stable/", None),
     "mpl_interactions": (
-        "https://mpl-interactions.readthedocs.io/en/stable",
+        f"https://mpl-interactions.readthedocs.io/en/{RELEASES['mpl-interactions']}",
         None,
     ),
     "numpy": ("https://numpy.org/doc/stable", None),
