@@ -1,5 +1,6 @@
 # flake8: noqa
-# pylint: disable=invalid-name
+# pylint: disable=import-error,invalid-name
+# pyright: reportMissingImports=False
 
 """Extend docstrings of the API.
 
@@ -7,8 +8,15 @@ This small script is used by ``conf.py`` to dynamically modify docstrings.
 """
 
 import inspect
-from typing import Callable, Type, Union
+import logging
+import textwrap
+from typing import Callable, Dict, Optional, Type, Union
 
+import attr
+
+# sphinx.ext.graphviz does not work well on RTD
+import graphviz  # type: ignore
+import qrules
 import sympy as sp
 
 from ampform.dynamics import (
@@ -25,6 +33,13 @@ from ampform.dynamics import (
     relativistic_breit_wigner_with_ff,
 )
 from ampform.dynamics.math import ComplexSqrt
+from ampform.helicity import (
+    formulate_clebsch_gordan_coefficients,
+    formulate_wigner_d,
+)
+from ampform.kinematics import get_helicity_angle_label
+
+logging.getLogger().setLevel(logging.ERROR)
 
 
 def update_docstring(
@@ -43,6 +58,7 @@ def render_blatt_weisskopf() -> None:
         f"""
     .. math:: {sp.latex(ff2)} = {sp.latex(ff2.doit())}
         :label: BlattWeisskopfSquared
+        :class: full-width
     """,
     )
 
@@ -124,6 +140,82 @@ def render_coupled_width() -> None:
     )
 
 
+def render_formulate_wigner_d() -> None:
+    update_docstring(
+        formulate_wigner_d,
+        __get_graphviz_state_transition_example("helicity"),
+    )
+
+
+def render_formulate_clebsch_gordan_coefficients() -> None:
+    update_docstring(
+        formulate_clebsch_gordan_coefficients,
+        __get_graphviz_state_transition_example(
+            formalism="canonical-helicity", transition_number=1
+        ),
+    )
+
+
+def __get_graphviz_state_transition_example(
+    formalism: str, transition_number: int = 0
+) -> str:
+    reaction = qrules.generate_transitions(
+        initial_state=[("J/psi(1S)", [+1])],
+        final_state=[("gamma", [-1]), "f(0)(980)"],
+        formalism=formalism,
+    )
+    transition = reaction.transitions[transition_number]
+    new_interaction = attr.evolve(
+        transition.interactions[0],
+        parity_prefactor=None,
+    )
+    interactions = dict(transition.interactions)
+    interactions[0] = new_interaction
+    transition = attr.evolve(transition, interactions=interactions)
+    dot = qrules.io.asdot(
+        transition,
+        render_initial_state_id=True,
+        render_node=True,
+    )
+    for state_id in [0, 1, -1]:
+        dot = dot.replace(
+            f'label="{state_id}: ',
+            f'label="{state_id+2}: ',
+        )
+    return _graphviz_to_image(dot, indent=4, options={"align": "center"})
+
+
+def render_get_helicity_angle_label() -> None:
+    topologies = qrules.topology.create_isobar_topologies(5)
+    dot0, dot1, *_ = tuple(
+        map(lambda t: qrules.io.asdot(t, render_resonance_id=True), topologies)
+    )
+    graphviz0 = _graphviz_to_image(
+        dot0,
+        indent=6,
+        caption=":code:`topologies[0]`",
+        label="one-to-five-topology-0",
+    )
+    graphviz1 = _graphviz_to_image(
+        dot1,
+        indent=6,
+        caption=":code:`topologies[1]`",
+        label="one-to-five-topology-1",
+    )
+    update_docstring(
+        get_helicity_angle_label,
+        f"""
+
+    .. panels::
+      :body: text-center
+      {graphviz0}
+
+      ---
+      {graphviz1}
+    """,
+    )
+
+
 def render_phase_space_factor() -> None:
     s, m_a, m_b = sp.symbols("s, m_a, m_b")
     rho = phase_space_factor(s, m_a, m_b)
@@ -264,3 +356,32 @@ def insert_math() -> None:
                 f"Local function {name} should not have a signature"
             )
         definition()
+
+
+_GRAPHVIZ_COUNTER = 0
+_IMAGE_DIR = "_images"
+
+
+def _graphviz_to_image(  # pylint: disable=too-many-arguments
+    dot: str,
+    options: Optional[Dict[str, str]] = None,
+    format: str = "svg",
+    indent: int = 0,
+    caption: str = "",
+    label: str = "",
+) -> str:
+    if options is None:
+        options = {}
+    global _GRAPHVIZ_COUNTER  # pylint: disable=global-statement
+    output_file = f"graphviz_{_GRAPHVIZ_COUNTER}"
+    _GRAPHVIZ_COUNTER += 1
+    graphviz.Source(dot).render(f"{_IMAGE_DIR}/{output_file}", format=format)
+    restructuredtext = "\n"
+    if label:
+        restructuredtext += f".. _{label}:\n"
+    restructuredtext += f".. figure:: /{_IMAGE_DIR}/{output_file}.{format}\n"
+    for option, value in options.items():
+        restructuredtext += f"  :{option}: {value}\n"
+    if caption:
+        restructuredtext += f"\n  {caption}\n"
+    return textwrap.indent(restructuredtext, indent * " ")
