@@ -13,8 +13,8 @@ from sympy.printing.latex import LatexPrinter
 
 from .decorator import (
     UnevaluatedExpression,
+    create_expression,
     implement_doit_method,
-    verify_signature,
 )
 from .math import ComplexSqrt
 
@@ -60,10 +60,7 @@ class BlattWeisskopfSquared(UnevaluatedExpression):
         **hints: Any,
     ) -> "BlattWeisskopfSquared":
         args = sp.sympify((angular_momentum, z))
-        if evaluate:
-            # pylint: disable=no-member
-            return sp.Expr.__new__(cls, *args, **hints).evaluate()
-        return sp.Expr.__new__(cls, *args, **hints)
+        return create_expression(cls, evaluate, *args, **hints)
 
     def evaluate(self) -> sp.Expr:
         angular_momentum, z = self.args
@@ -296,8 +293,6 @@ def coupled_width(  # pylint: disable=too-many-arguments
     """
     if phsp_factor is None:
         phsp_factor = phase_space_factor
-    else:
-        verify_signature(phsp_factor, PhaseSpaceFactor)
     assert phsp_factor is not None  # pyright v1.1.151
     q_squared = breakup_momentum_squared(s, m_a, m_b)
     q0_squared = breakup_momentum_squared(mass0 ** 2, m_a, m_b)
