@@ -17,9 +17,6 @@ from . import (
     relativistic_breit_wigner_with_ff,
 )
 
-# pyright: reportUnusedImport=false
-from .decorator import verify_signature  # noqa: F401
-
 try:
     from typing import Protocol
 except ImportError:
@@ -124,7 +121,7 @@ def _make_relativistic_breit_wigner_with_ff(
     phsp_factor: PhaseSpaceFactor,
     docstring: str,
 ) -> ResonanceDynamicsBuilder:
-    """Factory for a `.ResonanceDynamicsBuilder` that uses `.relativistic_breit_wigner_with_ff`."""
+    """Factory for `.relativistic_breit_wigner_with_ff`."""
 
     def dynamics_builder(
         resonance: Particle, variable_pool: TwoBodyKinematicVariableSet
