@@ -1,9 +1,7 @@
 """Tools for defining lineshapes with `sympy`."""
 
-import inspect
 from abc import abstractmethod
-from collections import OrderedDict
-from typing import Any, Callable, Type
+from typing import Any, Callable, Optional, Type
 
 import sympy as sp
 from sympy.printing.latex import LatexPrinter
@@ -103,28 +101,18 @@ def implement_doit_method() -> Callable[
     return decorator
 
 
-def verify_signature(builder: Callable, protocol: Type[Callable]) -> None:
-    """Check signature of a builder function dynamically.
+def create_expression(
+    cls: Type[UnevaluatedExpression], evaluate: bool, *args: Any, **kwargs: Any
+) -> sp.Expr:
+    """Helper function for implementing :code:`Expr.__new__`.
 
-    Dynamically check whether a builder has the same signature as that of the
-    given `~typing.Protocol` (a `~typing.Callable`). This function is needed
-    because :func:`typing.runtime_checkable` only checks members and methods, not the
-    signature of those methods.
+    See e.g. source code of `.BlattWeisskopfSquared`.
     """
-    expected_signature = inspect.signature(protocol.__call__)
-    signature = inspect.signature(builder)
-    if signature.return_annotation != expected_signature.return_annotation:
-        raise ValueError(
-            f'Builder "{builder.__name__}" has return type {expected_signature.return_annotation};'
-            f" expected {signature.return_annotation}"
-        )
-    expected_parameters = OrderedDict(expected_signature.parameters.items())
-    del expected_parameters["self"]
-    assert signature.return_annotation == expected_signature.return_annotation
-    if signature.parameters != expected_parameters:
-        raise ValueError(
-            f'Builder "{builder.__name__}" has parameters\n'
-            f"  {list(signature.parameters.values())}\n"
-            "This should be\n"
-            f"  {list(expected_parameters.values())}"
-        )
+    # pylint: disable=no-member
+    deep: Optional[bool] = kwargs.pop("deep", None)
+    expr = sp.Expr.__new__(cls, *args, **kwargs)
+    if evaluate:
+        expr = expr.evaluate()
+    if deep:
+        expr = expr.doit(deep=deep)
+    return expr
