@@ -32,7 +32,6 @@ from sympy.printing.latex import LatexPrinter
 from ampform.dynamics.builder import (
     ResonanceDynamicsBuilder,
     TwoBodyKinematicVariableSet,
-    verify_signature,
 )
 from ampform.kinematics import (
     HelicityAdapter,
@@ -40,7 +39,7 @@ from ampform.kinematics import (
     get_invariant_mass_label,
 )
 
-from .decay import TwoBodyDecay, get_angular_momentum, get_coupled_spin
+from .decay import TwoBodyDecay
 from .naming import (
     CanonicalAmplitudeNameGenerator,
     HelicityAmplitudeNameGenerator,
@@ -150,7 +149,6 @@ class HelicityAmplitudeBuilder:
     def set_dynamics(
         self, particle_name: str, dynamics_builder: ResonanceDynamicsBuilder
     ) -> None:
-        verify_signature(dynamics_builder, ResonanceDynamicsBuilder)
         for transition in self.__reaction.transitions:
             for node_id in transition.topology.nodes:
                 decay = TwoBodyDecay.from_transition(transition, node_id)
@@ -258,7 +256,7 @@ class HelicityAmplitudeBuilder:
     def __generate_amplitude_coefficient(
         self, transition: StateTransition
     ) -> sp.Symbol:
-        """Generate coefficient parameter for a sequential amplitude transition.
+        """Generate coefficient parameter for a sequential amplitude.
 
         Generally, each partial amplitude of a sequential amplitude transition
         should check itself if it or a parity partner is already defined. If so
@@ -337,25 +335,60 @@ def extract_particle_collection(
 def formulate_clebsch_gordan_coefficients(
     transition: StateTransition, node_id: int
 ) -> sp.Expr:
-    """Compute two Clebsch-Gordan coefficients for a state transition node.
+    r"""Compute the two Clebsch-Gordan coefficients for a state transition node.
 
+    In the **canonical basis** (also called **partial wave basis**),
+    :doc:`Clebsch-Gordan coefficients <sympy:modules/physics/quantum/cg>`
+    ensure that the projection of angular momentum is conserved
+    (:cite:`kutschkeAngularDistributionCookbook1996`, p. 4). When calling
+    :func:`~qrules.generate_transitions` with
+    :code:`formalism="canonical-helicity"`, AmpForm formulates the amplitude in
+    the canonical basis from amplitudes in the helicity basis using the
+    transformation in :cite:`chungSpinFormalismsUpdated2014`, Eq. (4.32). See
+    also :cite:`kutschkeAngularDistributionCookbook1996`, Eq. (28).
+
+    This function produces the two Clebsch-Gordan coefficients in
+    :cite:`chungSpinFormalismsUpdated2014`, Eq. (4.32). For a two-body decay
+    :math:`1 \to 2, 3`, we get:
+
+    .. math:: C^{s_1,\lambda}_{L,0,S,\lambda} C^{S,\lambda}_{s_2,\lambda_2,s_3,-\lambda_3}
+        :label: formulate_clebsch_gordan_coefficients
+
+    with:
+
+    - :math:`s_i` the intrinsic `Spin.magnitude
+      <qrules.particle.Spin.magnitude>` of each state :math:`i`,
+    - :math:`\lambda_{2}, \lambda_{3}` the helicities of the decay products
+      (can be taken to be their `~qrules.transition.State.spin_projection` when
+      following a constistent boosting procedure),
+    - :math:`\lambda=\lambda_{2}-\lambda_{3}`,
+    - :math:`L` the *total* angular momentum of the final state pair
+      (`~qrules.quantum_numbers.InteractionProperties.l_magnitude`),
+    - :math:`S` the coupled spin magnitude of the final state pair
+      (`~qrules.quantum_numbers.InteractionProperties.s_magnitude`),
+    - and :math:`C^{j_3,m_3}_{j_1,m_1,j_2,m_2} = \langle
+      j1,m1;j2,m2|j3,m3\rangle`, as in :doc:`sympy:modules/physics/quantum/cg`.
+
+    Example
+    -------
     >>> import qrules
     >>> reaction = qrules.generate_transitions(
     ...     initial_state=[("J/psi(1S)", [+1])],
-    ...     final_state=[("gamma", [+1]), "f(0)(980)"],
+    ...     final_state=[("gamma", [-1]), "f(0)(980)"],
     ... )
-    >>> transition = reaction.transitions[0]
+    >>> transition = reaction.transitions[1]  # angular momentum 2
     >>> formulate_clebsch_gordan_coefficients(transition, node_id=0)
-    CG(0, 0, 1, 1, 1, 1)*CG(1, 1, 0, 0, 1, 1)
+    CG(1, -1, 0, 0, 1, -1)*CG(2, 0, 1, -1, 1, -1)
 
-    .. seealso:: :doc:`sympy:modules/physics/quantum/cg`
+    .. math::
+        C^{s_1,\lambda}_{L,0,S,\lambda} C^{S,\lambda}_{s_2,\lambda_2,s_3,-\lambda_3}
+        = C^{1,(-1-0)}_{2,0,1,(-1-0)} C^{1,(-1-0)}_{1,-1,0,0}
+        = C^{1,-1}_{2,0,1,-1} C^{1,-1}_{1,-1,0,0}
     """
     decay = TwoBodyDecay.from_transition(transition, node_id)
 
-    angular_momentum = get_angular_momentum(decay.interaction)
-    coupled_spin = get_coupled_spin(decay.interaction)
-    if angular_momentum.projection != 0.0:
-        raise ValueError(f"Projection of L is non-zero!: {angular_momentum}")
+    angular_momentum = decay.interaction.l_magnitude
+    coupled_spin = decay.interaction.s_magnitude
 
     parent = decay.parent
     child1 = decay.children[0]
@@ -363,9 +396,9 @@ def formulate_clebsch_gordan_coefficients(
 
     decay_particle_lambda = child1.spin_projection - child2.spin_projection
     cg_ls = CG(
-        j1=sp.Rational(angular_momentum.magnitude),
-        m1=sp.Rational(angular_momentum.projection),
-        j2=sp.Rational(coupled_spin.magnitude),
+        j1=sp.Rational(angular_momentum),
+        m1=0,
+        j2=sp.Rational(coupled_spin),
         m2=sp.Rational(decay_particle_lambda),
         j3=sp.Rational(parent.particle.spin),
         m3=sp.Rational(decay_particle_lambda),
@@ -375,23 +408,55 @@ def formulate_clebsch_gordan_coefficients(
         m1=sp.Rational(child1.spin_projection),
         j2=sp.Rational(child2.particle.spin),
         m2=sp.Rational(-child2.spin_projection),
-        j3=sp.Rational(coupled_spin.magnitude),
+        j3=sp.Rational(coupled_spin),
         m3=sp.Rational(decay_particle_lambda),
     )
     return sp.Mul(cg_ls, cg_ss, evaluate=False)
 
 
 def formulate_wigner_d(transition: StateTransition, node_id: int) -> sp.Expr:
-    """Compute `~sympy.physics.quantum.spin.WignerD` for a state transition node.
+    r"""Compute `~sympy.physics.quantum.spin.WignerD` for a transition node.
 
+    Following :cite:`kutschkeAngularDistributionCookbook1996`, Eq. (10). For a
+    two-body decay :math:`1 \to 2, 3`, we get
+
+    .. math:: D^{s_1}_{m_1,\lambda_2-\lambda_3}(-\phi,\theta,0)
+        :label: formulate_wigner_d
+
+    with:
+
+    - :math:`s_1` the `Spin.magnitude <qrules.particle.Spin.magnitude>` of the
+      decaying state,
+    - :math:`m_1` the `~qrules.transition.State.spin_projection` of the
+      decaying state,
+    - :math:`\lambda_{2}, \lambda_{3}` the helicities of the decay products in
+      in the restframe of :math:`1` (can be taken to be their intrinsic
+      `~qrules.transition.State.spin_projection` when following a constistent
+      boosting procedure),
+    - and :math:`\phi` and :math:`\theta` the helicity angles (see also
+      :func:`.get_helicity_angle_label`).
+
+    Note that :math:`\lambda_2, \lambda_3` are ordered by their number of
+    children, then by their state ID (see :class:`.TwoBodyDecay`).
+
+    See :cite:`kutschkeAngularDistributionCookbook1996`, Eq. (30) for an
+    example of Wigner-:math:`D` functions in a *sequential* two-body decay.
+
+    Example
+    -------
     >>> import qrules
     >>> reaction = qrules.generate_transitions(
     ...     initial_state=[("J/psi(1S)", [+1])],
-    ...     final_state=[("gamma", [+1]), "f(0)(980)"],
+    ...     final_state=[("gamma", [-1]), "f(0)(980)"],
     ... )
     >>> transition = reaction.transitions[0]
     >>> formulate_wigner_d(transition, node_id=0)
-    WignerD(1, 1, 1, -phi_0, theta_0, 0)
+    WignerD(1, 1, -1, -phi_0, theta_0, 0)
+
+    .. math::
+        D^{s_1}_{m_1,\lambda_2-\lambda_3}\left(-\phi,\theta,0\right)
+        = D^{1}_{+1,(-1-0)}\left(-\phi_0,\theta_0,0\right)
+        = D^{1}_{1,-1}\left(-\phi_0,\theta_0,0\right)
     """
     decay = TwoBodyDecay.from_transition(transition, node_id)
     _, phi, theta = _generate_kinematic_variables(transition, node_id)
@@ -409,7 +474,10 @@ def formulate_wigner_d(transition: StateTransition, node_id: int) -> sp.Expr:
 
 
 def get_prefactor(transition: StateTransition) -> float:
-    """Calculate the product of all prefactors defined in this transition."""
+    """Calculate the product of all prefactors defined in this transition.
+
+    .. seealso:: `qrules.quantum_numbers.InteractionProperties.parity_prefactor`
+    """
     prefactor = 1.0
     for node_id in transition.topology.nodes:
         interaction = transition.interactions[node_id]
