@@ -1,3 +1,4 @@
+# cspell:ignore rpartition
 # pylint: disable=redefined-builtin
 """Create interactive plots for `sympy` expressions.
 
@@ -7,6 +8,10 @@ this module.
 
 The module is only available here, under the documentation. If this feature
 turns out to be popular, it can be published as an independent package.
+
+The package also provides other helpful functions, like
+:func:`substitute_indexed_symbols`, that are useful when visualizing
+`sympy` expressions.
 """
 
 import inspect
@@ -19,12 +24,14 @@ from typing import (
     Iterator,
     Mapping,
     Tuple,
+    Type,
     TypeVar,
     Union,
 )
 
 import sympy as sp
 from ipywidgets.widgets import FloatSlider, IntSlider
+from sympy.printing.latex import translate
 
 try:
     from IPython.lib.pretty import PrettyPrinter
@@ -34,16 +41,16 @@ except ImportError:
 Slider = Union[FloatSlider, IntSlider]
 RangeDefinition = Union[
     Tuple[float, float],
-    Tuple[float, float, int],
+    Tuple[float, float, Union[float, int]],
 ]
 
 
 class SliderKwargs(abc.Mapping):
     """Wrapper around a `dict` of sliders that can serve as keyword arguments.
 
-    Sliders can be defined in :func:`mpl_interactions.interactive_plot` through
-    :term:`kwargs <python:keyword argument>`. This wrapper class can be used
-    for that.
+    Sliders can be defined in :func:`~mpl_interactions.pyplot.interactive_plot`
+    through :term:`kwargs <python:keyword argument>`. This wrapper class can be
+    used for that.
     """
 
     def __init__(
@@ -52,11 +59,11 @@ class SliderKwargs(abc.Mapping):
         arg_to_symbol: Mapping[str, str],
     ) -> None:
         self._verify_arguments(sliders, arg_to_symbol)
-        self.__sliders = dict(sliders)
-        self.__arg_to_symbol = {
+        self._sliders = dict(sliders)
+        self._arg_to_symbol = {
             arg: symbol
             for arg, symbol in arg_to_symbol.items()
-            if symbol in self.__sliders
+            if symbol in self._sliders
         }
 
     @staticmethod
@@ -90,13 +97,13 @@ class SliderKwargs(abc.Mapping):
         """Get slider by symbol, symbol name, or argument name."""
         if isinstance(key, sp.Symbol):
             key = key.name
-        if key in self.__arg_to_symbol:
-            slider_name = self.__arg_to_symbol[key]
+        if key in self._arg_to_symbol:
+            slider_name = self._arg_to_symbol[key]
         else:
             slider_name = key
-        if slider_name not in self.__sliders:
+        if slider_name not in self._sliders:
             raise KeyError(f'"{key}" is neither an argument nor a symbol name')
-        return self.__sliders[slider_name]
+        return self._sliders[slider_name]
 
     def __iter__(self) -> Iterator[str]:
         """Iterate over the arguments of the `.LambdifiedExpression`.
@@ -104,16 +111,16 @@ class SliderKwargs(abc.Mapping):
         This is useful for unpacking an instance of `SliderKwargs` as
         :term:`kwargs <python:keyword argument>`.
         """
-        return self.__arg_to_symbol.__iter__()
+        return self._arg_to_symbol.__iter__()
 
     def __len__(self) -> int:
-        return len(self.__sliders)
+        return len(self._sliders)
 
     def __repr__(self) -> str:
         return (
             f"{self.__class__.__name__}("
-            f"sliders={self.__sliders}, "
-            f"arg_to_symbol={self.__arg_to_symbol})"
+            f"sliders={self._sliders}, "
+            f"arg_to_symbol={self._arg_to_symbol})"
         )
 
     def _repr_pretty_(self, p: PrettyPrinter, cycle: bool) -> None:
@@ -124,11 +131,11 @@ class SliderKwargs(abc.Mapping):
             with p.group(indent=2, open=f"{class_name}("):
                 p.breakable()
                 p.text("sliders=")
-                p.pretty(self.__sliders)
+                p.pretty(self._sliders)
                 p.text(",")
                 p.breakable()
                 p.text("arg_to_symbol=")
-                p.pretty(self.__arg_to_symbol)
+                p.pretty(self._arg_to_symbol)
                 p.text(",")
             p.breakable()
             p.text(")")
@@ -151,10 +158,15 @@ class SliderKwargs(abc.Mapping):
                 )
                 continue
 
-    def set_ranges(
+    def set_ranges(  # noqa: R701
         self, *args: Dict[str, RangeDefinition], **kwargs: RangeDefinition
     ) -> None:
-        """Set min, max and (optionally) the number of steps for each slider."""
+        """Set min, max and (optionally) the nr of steps for each slider.
+
+        .. tip::
+            :code:`n_steps` becomes the step **size** if its value is
+            `float`.
+        """
         range_definitions = _merge_args_kwargs(*args, **kwargs)
         for slider_name, range_def in range_definitions.items():
             if not isinstance(range_def, tuple):
@@ -169,7 +181,10 @@ class SliderKwargs(abc.Mapping):
                 min_, max_, n_steps = range_def  # type: ignore
                 if n_steps <= 0:
                     raise ValueError("Number of steps has to be positive")
-                step_size = (max_ - min_) / n_steps
+                if isinstance(n_steps, float):
+                    step_size = n_steps
+                else:
+                    step_size = (max_ - min_) / n_steps
             else:
                 raise ValueError(
                     f'Range definition {range_def} for slider "{slider_name}"'
@@ -224,16 +239,16 @@ def prepare_sliders(
     SliderKwargs(...)
     """
     slider_symbols = _extract_slider_symbols(expression, plot_symbol)
-    sliders_mapping = {
-        symbol.name: create_slider(symbol) for symbol in slider_symbols
-    }
     lambdified_expression = sp.lambdify(
         (plot_symbol, *slider_symbols),
         expression,
-        "numpy",
+        modules="numpy",
     )
-    symbols_names = list(map(lambda s: s.name, (plot_symbol, *slider_symbols)))
-    arg_names = list(inspect.signature(lambdified_expression).parameters)
+    sliders_mapping = {
+        symbol.name: create_slider(symbol) for symbol in slider_symbols
+    }
+    symbols_names = map(lambda s: s.name, (plot_symbol, *slider_symbols))
+    arg_names = inspect.signature(lambdified_expression).parameters
     arg_to_symbol = dict(zip(arg_names, symbols_names))
     sliders = SliderKwargs(sliders_mapping, arg_to_symbol)
     return lambdified_expression, sliders
@@ -268,3 +283,48 @@ def _extract_slider_symbols(
         )
     ordered_symbols = sorted(expression.free_symbols, key=lambda s: s.name)
     return tuple(s for s in ordered_symbols if s != plot_symbol)
+
+
+def partial_doit(
+    expression: sp.Expr,
+    doit_classes: Union[Type[sp.Basic], Tuple[Type[sp.Basic]]],
+) -> sp.Expr:
+    """Perform :meth:`~sympy.core.basic.Basic.doit` up to a certain level.
+
+    Arguments
+    ---------
+    expression: the `~sympy.core.expr.Expr` on which you want to perform a
+        :meth:`~sympy.core.basic.Basic.doit`.
+    doit_classes: types on which the :meth:`~sympy.core.basic.Basic.doit`
+        should be performed.
+    """
+    new_expression = expression
+    for node in sp.preorder_traversal(expression):
+        if isinstance(node, doit_classes):
+            new_expression = new_expression.xreplace(
+                {node: node.doit(deep=False)}
+            )
+    return new_expression
+
+
+def _indexed_to_symbol(idx: sp.Indexed) -> sp.Symbol:
+    base_name, _, _ = str(idx).rpartition("[")
+    subscript = ",".join(map(str, idx.indices))
+    if len(idx.indices) > 1:
+        base_name = translate(base_name)
+        subscript = "_{" + subscript + "}"
+    return sp.Symbol(f"{base_name}{subscript}")
+
+
+def substitute_indexed_symbols(expression: sp.Expr) -> sp.Expr:
+    """Substitute `~sympy.tensor.indexed.IndexedBase` with symbols.
+
+    See :doc:`compwa-org:report/008` for more info.
+    """
+    return expression.subs(
+        {
+            s: _indexed_to_symbol(s)
+            for s in expression.free_symbols
+            if isinstance(s, sp.Indexed)
+        }
+    )
